import { CSSProperties } from 'react';
import { MemoExoticComponent } from 'react';
import { ReactElement } from 'react';

declare type JsonArray = JsonValue[];

declare interface JsonObject {
    [key: string]: JsonValue;
}

declare type JsonValue = Primitive | JsonObject | JsonArray;

/**
 * Renders a JSON Viewer component that displays JSON data in a collapsible tree format.
 *
 * The `JsonViewer` component provides a visual representation of JSON data with features
 * such as collapsible nodes and custom styling options. It leverages the `JsonViewerContent`
 * for rendering the actual content and `CollapsibleProvider` for managing the collapsible state.
 *
 * @component
 * @param {JsonViewerProps} props - The properties passed to the JsonViewer component.
 * @param {object} props.data - The JSON data to be visualized by the JsonViewer.
 * @param {string} [props.rootName="root"] - The root name to be displayed at the root level of the JSON structure.
 * @param {React.CSSProperties} [props.style] - Optional CSS styles to be applied to the JsonViewer component.
 * @param {number} [props.expandLevel=0] - The initial level to which the JSON structure is expanded.
 * @param {Function} [props.onCopy] - Optional callback function to be invoked when a copy action is performed.
 *
 * @returns {ReactElement} A React Element that represents the JSON Viewer component.
 *
 * @example
 * <JsonViewer
 *   data={{ key: 'value', nested: { anotherKey: 'anotherValue' } }}
 *   rootName="Example JSON"
 *   expandLevel={1}
 *   onCopy={(copyInfo) => console.log('Copy action:', copyInfo)}
 * />
 */
export declare const JsonViewer: MemoExoticComponent<({ data, rootName, style, expandLevel, onCopy, }: JsonViewerProps) => ReactElement>;

declare interface JsonViewerProps {
    data: JsonValue;
    rootName?: string;
    style?: CSSProperties;
    expandLevel?: number;
    copy?: boolean;
    onCopy?: (info: {
        keys: string[];
        value: JsonValue;
    }) => void;
}

declare type Primitive = string | number | boolean | null;

export { }
